@@ -5,7 +5,7 @@
 #################################################################
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-##Version: 0.3-0
+##Version: 0.3-1
 
 import os
 import sys
@@ -71,7 +71,7 @@ def doUpdateConfig():
 
     time.sleep(1)
     try:
-       os.system('cp %s %s' % (Path + ConfigFile, MainPath + MainFile))
+       os.system('sudo %supdateTuning copyTuning_temp' % AppPath)
     except:
        return False
     else: 
@@ -119,7 +119,7 @@ class MyMainWindow(QtGui.QMainWindow):
              QMessageBox.about(self, "Credits - SWAPPOLUBE Editor", msg)
  
         def doDeleteTunings(self): ##FIXME: check if file was deleted!!
-             os.system('rm /etc/event.d/tuning')
+             os.system('sudo %supdateTuning deleteTuning' % AppPath)
              message = 'The tuning file has been removed from the boot sequence.\nOn next reboot, the system will start with its default configuration.'
              showMessage(message)
 
